@@ -11,6 +11,7 @@ __credits__ = "Leo Singer <leo.singer@ligo.org>"
 import os
 import stat
 from unittest import mock
+from urllib.parse import urlencode
 
 import pytest
 
@@ -75,11 +76,11 @@ class TestSession:
         )
 
         # with the kwarg a RequestException is raised
-        with pytest.raises(RequestException) as exc:
+        with pytest.raises(
+            RequestException,
+            match=r"404 Client Error: not found for url: https://test.org/",
+        ):
             igwn_requests.get("https://test.org")
-        assert str(exc.value) == (
-            "404 Client Error: not found for url: https://test.org/"
-        )
 
     # -- SessionAuthMixin
 
@@ -153,11 +154,10 @@ class TestSession:
             self.Session(token=True)
 
     @pytest.mark.parametrize(("url", "aud"), (
-        ("https://secret.example.com:8008", list({
-            "https://secret.example.com:8008",
+        ("https://secret.example.com:8008", [
             "https://secret.example.com",
             "ANY",
-        })),
+        ]),
         (None, None)
     ))
     @mock.patch("igwn_auth_utils.requests.find_scitoken")
@@ -257,5 +257,23 @@ def test_get_session(mock_session):
     """
     session = mock.MagicMock()
     assert igwn_requests.get("https://test.org", session=session)
-    session.get.assert_called_once_with("https://test.org")
+    session.request.assert_called_once_with("get", "https://test.org")
     mock_session.assert_not_called()
+
+
+def test_post(requests_mock):
+    """Test that `igwn_auth_utils.requests.post` can perform a simple request.
+    """
+    data = {"a": 1, "b": 2}
+    requests_mock.post(
+        "https://example.com",
+        text="THANKS",
+    )
+    # check that the correct response got passed through
+    assert igwn_requests.post(
+        "https://example.com",
+        data=data,
+    ).text == "THANKS"
+    # check that the data was encoded into the request properly
+    req = requests_mock.request_history[0]
+    assert req.body == urlencode(data)
